<?php
/**
 * Post Settings
 *
 * Register Post Settings section, settings and controls for Theme Customizer
 *
 * @package Salal
 */

/**
 * Adds post settings in the Customizer
 *
 * @param object $wp_customize / Customizer Object.
 */
function salal_customize_register_post_settings( $wp_customize ) {

	// Add Sections for Post Settings.
	$wp_customize->add_section( 'salal_section_post', array(
		'title'    => esc_html__( 'Post Settings', 'salal' ),
		'priority' => 40,
		'panel' => 'salal_options_panel',
	) );
	
	// Add Post Layout Headline.
	$wp_customize->add_control( new Salal_Customize_Header_Control(
		$wp_customize, 'salal_theme_options[post_layout_option]', array(
			'label' => esc_html__( 'Post Layout', 'salal' ),
			'section' => 'salal_section_post',
			'settings' => array(),
		)
	) );

	// Add Settings and Controls for Layout.
	$wp_customize->add_setting( 'salal_theme_options[sidebar_position_post]', array(
		'default'           => 'right',
		'type'              => 'option',
		'transport'         => 'postMessage',
		'sanitize_callback' => 'salal_sanitize_select',
	) );

	$wp_customize->add_control( 'salal_theme_options[sidebar_position_post]', array(
		'label'    => esc_html__( 'Sidebar Position', 'salal' ),
		'description' => esc_html__( 'This will let you choose your sidebar position for the full post layout.', 'salal' ), 
		'section'  => 'salal_section_post',
		'settings' => 'salal_theme_options[sidebar_position_post]',
		'type'     => 'radio',
		'choices'  => array(
			'left'  => esc_html__( 'Left Sidebar', 'salal' ),
			'right' => esc_html__( 'Right Sidebar', 'salal' ),
			'none' => esc_html__( 'No Sidebar', 'salal' ),
		),
	) );	
		
	// Add Post Details Headline.
	$wp_customize->add_control( new Salal_Customize_Header_Control(
		$wp_customize, 'salal_theme_options[post_details]', array(
			'label' => esc_html__( 'Post Details', 'salal' ),
			'section' => 'salal_section_post',
			'settings' => array(),
		)
	) );

	// Add Setting and Control for showing post date.
	$wp_customize->add_setting( 'salal_theme_options[meta_date]', array(
		'default'           => true,
		'type'           	=> 'option',
		'transport'         => 'postMessage',
		'sanitize_callback' => 'salal_sanitize_checkbox',
	) );

	$wp_customize->add_control( 'salal_theme_options[meta_date]', array(
		'label'    => esc_html__( 'Display date', 'salal' ),
		'section'  => 'salal_section_post',
		'settings' => 'salal_theme_options[meta_date]',
		'type'     => 'checkbox',
	) );

	// Add Setting and Control for showing post author.
	$wp_customize->add_setting( 'salal_theme_options[meta_author]', array(
		'default'           => true,
		'type'           	=> 'option',
		'transport'         => 'postMessage',
		'sanitize_callback' => 'salal_sanitize_checkbox',
	) );

	$wp_customize->add_control( 'salal_theme_options[meta_author]', array(
		'label'    => esc_html__( 'Display author', 'salal' ),
		'section'  => 'salal_section_post',
		'settings' => 'salal_theme_options[meta_author]',
		'type'     => 'checkbox',
	) );
	
	// Add Setting and Control for showing the single post category.
	$wp_customize->add_setting( 'salal_theme_options[post_category]', array(
		'default'           => true,
		'type'           	=> 'option',
		'transport'         => 'postMessage',
		'sanitize_callback' => 'salal_sanitize_checkbox',
	) );

	$wp_customize->add_control( 'salal_theme_options[post_category]', array(
		'label'    => esc_html__( 'Display the Single Post Category', 'salal' ),
		'section'  => 'salal_section_post',
		'settings' => 'salal_theme_options[post_category]',
		'type'     => 'checkbox',
	) );	
	


	// Add Single Post Headline.
	$wp_customize->add_control( new Salal_Customize_Header_Control(
		$wp_customize, 'salal_theme_options[single_post]', array(
			'label' => esc_html__( 'Single Post', 'salal' ),
			'section' => 'salal_section_post',
			'settings' => array(),
		)
	) );

	// Add Setting and Control for showing post categories.
	$wp_customize->add_setting( 'salal_theme_options[meta_category]', array(
		'default'           => true,
		'type'           	=> 'option',
		'transport'         => 'postMessage',
		'sanitize_callback' => 'salal_sanitize_checkbox',
	) );

	$wp_customize->add_control( 'salal_theme_options[meta_category]', array(
		'label'    => esc_html__( 'Display categories', 'salal' ),
		'section'  => 'salal_section_post',
		'settings' => 'salal_theme_options[meta_category]',
		'type'     => 'checkbox',
	) );
	
	// Add Setting and Control for showing post tags.
	$wp_customize->add_setting( 'salal_theme_options[meta_tags]', array(
		'default'           => true,
		'type'           	=> 'option',
		'transport'         => 'postMessage',
		'sanitize_callback' => 'salal_sanitize_checkbox',
	) );

	$wp_customize->add_control( 'salal_theme_options[meta_tags]', array(
		'label'    => esc_html__( 'Display tags', 'salal' ),
		'section'  => 'salal_section_post',
		'settings' => 'salal_theme_options[meta_tags]',
		'type'     => 'checkbox',
	) );

	// Add Setting and Control for showing post navigation.
	$wp_customize->add_setting( 'salal_theme_options[post_navigation]', array(
		'default'           => true,
		'type'           	=> 'option',
		'transport'         => 'postMessage',
		'sanitize_callback' => 'salal_sanitize_checkbox',
	) );

	$wp_customize->add_control( 'salal_theme_options[post_navigation]', array(
		'label'    => esc_html__( 'Display previous/next post navigation', 'salal' ),
		'section'  => 'salal_section_post',
		'settings' => 'salal_theme_options[post_navigation]',
		'type'     => 'checkbox',
	) );	
	
	// Add Featured Images Headline.
	$wp_customize->add_control( new Salal_Customize_Header_Control(
		$wp_customize, 'salal_theme_options[featured_images]', array(
		'label' => esc_html__( 'Featured Images', 'salal' ),
		'section' => 'salal_section_post',
		'settings' => array(),
		)
	) );

	// Add Setting and Control for featured images on blog and archives.
	$wp_customize->add_setting( 'salal_theme_options[post_image_archives]', array(
		'default'           => true,
		'type'           	=> 'option',
		'transport'         => 'postMessage',
		'sanitize_callback' => 'salal_sanitize_checkbox',
	) );

	$wp_customize->add_control( 'salal_theme_options[post_image_archives]', array(
		'label'    => esc_html__( 'Display images on blog and archives', 'salal' ),
		'section'  => 'salal_section_post',
		'settings' => 'salal_theme_options[post_image_archives]',
		'type'     => 'checkbox',
	) );

	$wp_customize->selective_refresh->add_partial( 'salal_theme_options[post_image_archives]', array(
		'selector'         => '.site-main .post-wrapper',
		'render_callback'  => 'salal_customize_partial_blog_content',
		'fallback_refresh' => false,
	) );

	// Add Setting and Control for featured images on single posts.
	$wp_customize->add_setting( 'salal_theme_options[post_image_single]', array(
		'default'           => true,
		'type'           	=> 'option',
		'transport'         => 'postMessage',
		'sanitize_callback' => 'salal_sanitize_checkbox',
	) );

	$wp_customize->add_control( 'salal_theme_options[post_image_single]', array(
		'label'    => esc_html__( 'Display image on single posts', 'salal' ),
		'section'  => 'salal_section_post',
		'settings' => 'salal_theme_options[post_image_single]',
		'type'     => 'checkbox',
	) );

	$wp_customize->selective_refresh->add_partial( 'salal_theme_options[post_image_single]', array(
		'selector'         => '.single-post .content-area .site-main',
		'render_callback'  => 'salal_customize_partial_single_post',
		'fallback_refresh' => false,
	) );
}
add_action( 'customize_register', 'salal_customize_register_post_settings' );


/**
 * Render single posts partial
 */
function salal_customize_partial_single_post() {
	while ( have_posts() ) {
		the_post();
		get_template_part( 'template-parts/posts/content', 'single' );
	}
}
