<?php
/**
 * Slider Settings
 *
 * Register Slider section, settings and controls for Theme Customizer
 *
 * @package Salal
 */

/**
 * Adds all slider settings to the Customizer
 *
 * @param object $wp_customize / Customizer Object.
 */
function salal_customize_register_slider_settings( $wp_customize ) {

	// Add Section for Theme Options.
	$wp_customize->add_section( 'salal_section_slider', array(
		'title'    => esc_html__( 'Slider Settings', 'salal' ),
		'priority' => 55,
		'panel'    => 'salal_options_panel',
	) );


	// Add Show Slider Headline.
	$wp_customize->add_control( new Salal_Customize_Header_Control(
		$wp_customize, 'salal_theme_options[display_slider_option]', array(
			'label' => esc_html__( 'Display Slider', 'salal' ),
			'section' => 'salal_section_slider',
			'settings' => array(),
		)
	) );

	// Display Slider
	$wp_customize->add_setting( 'salal_display_slider', array(
		'default'           => false,
		'sanitize_callback' => 'salal_sanitize_checkbox',
	) );

	$wp_customize->add_control( 'salal_display_slider', array(
		'label'    => esc_html__( 'Display the Slider', 'salal' ),
		'section'  => 'salal_section_slider',
		'type'     => 'checkbox',
	) );		
	
	// Slider category
	$wp_customize->add_setting( 'salal_theme_options[slider_cat]', array(
		'default' => '',
		'type'           	=> 'option',
		'sanitize_callback' => 'salal_sanitize_slidecat',
	) );

	$wp_customize->add_control( 'salal_theme_options[slider_cat]', array(
		'type' => 'select',
		'label' => esc_html__( 'Choose a category', 'salal' ),
		'description' => esc_html__( 'Choose your category to load slides from. Make sure your posts have featured images and we recommend also that you create a special category just for featured slide posts.', 'salal' ),
		'choices' => salal_slide_cats(),
		'section' => 'salal_section_slider',
	) );	
	
	
    /** No. of slides */
    $wp_customize->add_setting( 'salal_slide_count', array(
            'default'           => 3,
            'sanitize_callback' => 'absint'
        ) );
    
    $wp_customize->add_control( 'salal_slide_count', array(
            'type'        => 'number',
            'section'     => 'salal_section_slider',
            'label'       => esc_html__( 'Number of Slides', 'salal' ),
            'description' => esc_html__( 'Choose the total number of slides you want to display. This is for the total number of posts, not what is visible before scrolling.', 'salal' ),
            'input_attrs' => array(
				'min'   => 3,
				'max'   => 8,
				'step'  => 1,
            ),
        )
    );	
		
	// Add Slide Element Headline.
	$wp_customize->add_control( new Salal_Customize_Header_Control(
		$wp_customize, 'salal_theme_options[display_slider_elements]', array(
			'label' => esc_html__( 'Display Slider Elements', 'salal' ),
			'section' => 'salal_section_slider',
			'settings' => array(),
		)
	) );	
	
	// Display Slide category
	$wp_customize->add_setting( 'salal_theme_options[display_slide_cat]', array(
		'default'           => true,
		'type'           	=> 'option',
		'transport'         => 'postMessage',
		'sanitize_callback' => 'salal_sanitize_checkbox',
	) );

	$wp_customize->add_control( 'salal_theme_options[display_slide_cat]', array(
		'label'    => esc_html__( 'Display the Slide Category', 'salal' ),
		'section'  => 'salal_section_slider',
		'type'     => 'checkbox',
	) );	

	// Display Slide date
	$wp_customize->add_setting( 'salal_display_slide_date', array(
		'default'           => true,
		'transport'         => 'postMessage',
		'sanitize_callback' => 'salal_sanitize_checkbox',
	) );

	$wp_customize->add_control( 'salal_display_slide_date', array(
		'label'    => esc_html__( 'Display the Slide Post Date', 'salal' ),
		'section'  => 'salal_section_slider',
		'type'     => 'checkbox',
	) );	
	
	// Display Slide read more
	$wp_customize->add_setting( 'salal_display_slide_readmore', array(
		'default'           => true,
		'transport'         => 'postMessage',
		'sanitize_callback' => 'salal_sanitize_checkbox',
	) );

	$wp_customize->add_control( 'salal_display_slide_readmore', array(
		'label'    => esc_html__( 'Display the Slide Read More', 'salal' ),
		'section'  => 'salal_section_slider',
		'type'     => 'checkbox',
	) );	
	
	// Slider background
 	$wp_customize->add_setting( 'salal_slider_bg', array(
		'default'        => '#eef1f7',
		'transport'      => 'postMessage',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'salal_slider_bg', array(
		'label'   => esc_html__( 'Slider Background Colour', 'salal' ),
		'section' => 'salal_section_slider',
		'settings'   => 'salal_slider_bg',
	) ) );		

}
add_action( 'customize_register', 'salal_customize_register_slider_settings' );



/**
 * Function to list post categories in customizer options
 * This loads categories for our slider dropdown select
 */
function salal_slide_cats() {
	$cats = array();
	$cats[0] = 'All';

	foreach ( get_categories() as $categories => $category ) {
		$cats[ $category->term_id ] = $category->name;
	}
	return $cats;
}