<?php
/**
 * Thumbnail Settings
 * Register Thumbnails section, settings and controls for the Theme Customizer
 * Settings and controls to manage image thumbnail cropping
 *
 * @package Salal
 */

/**
 * Adds all layout settings to the Customizer
 *
 * @param object $wp_customize / Customizer Object.
 */
function salal_customize_register_thumbnail_settings( $wp_customize ) {

	// Add Section for Theme Options.
	$wp_customize->add_section( 'salal_section_thumbnails', array(
		'title'    => esc_html__( 'Thumbnail Settings', 'salal' ),
		'priority' => 50,
		'panel'    => 'salal_options_panel',
	) );

	// Add Featured Images Headline.
	$wp_customize->add_control( new Salal_Customize_Header_Control(
		$wp_customize, 'salal_theme_options[crop_featured_images]', array(
		'label' => esc_html__( 'Crop Blog Featured Images', 'salal' ),
		'section' => 'salal_section_thumbnails',
		'settings' => array(),
		)
	) );
	
	// Add Setting and Control for cropping Large featured images on blog and archives.
	$wp_customize->add_setting( 'salal_crop_large_featured', array(
		'default'           => false,
		'sanitize_callback' => 'salal_sanitize_checkbox',
	) );

	$wp_customize->add_control( 'salal_crop_large_featured', array(
		'label'    => esc_html__( 'Crop featured images for the Large Posts Layout', 'salal' ),
		'section'  => 'salal_section_thumbnails',
		'type'     => 'checkbox',
	) );	
	
	// Add Setting and Control for cropping List featured images on blog and archives.
	$wp_customize->add_setting( 'salal_crop_list_featured', array(
		'default'           => false,
		'sanitize_callback' => 'salal_sanitize_checkbox',
	) );

	$wp_customize->add_control( 'salal_crop_list_featured', array(
		'label'    => esc_html__( 'Crop featured images for the List Posts Layout', 'salal' ),
		'section'  => 'salal_section_thumbnails',
		'type'     => 'checkbox',
	) );		
	
	// Add Setting and Control for cropping Grid featured images on blog and archives.
	$wp_customize->add_setting( 'salal_crop_grid_featured', array(
		'default'           => false,
		'sanitize_callback' => 'salal_sanitize_checkbox',
	) );

	$wp_customize->add_control( 'salal_crop_grid_featured', array(
		'label'    => esc_html__( 'Crop featured images for the Grid Posts Layout', 'salal' ),
		'section'  => 'salal_section_thumbnails',
		'type'     => 'checkbox',
	) );		
	
	
	// Add Setting and Control for cropping the full post featured image.
	$wp_customize->add_setting( 'salal_crop_single_featured', array(
		'default'           => false,
		'type'           	=> 'option',
		'sanitize_callback' => 'salal_sanitize_checkbox',
	) );

	$wp_customize->add_control( 'salal_crop_single_featured', array(
		'label'    => esc_html__( 'Crop featured images for the Full Post.', 'salal' ),
		'section'  => 'salal_section_thumbnails',
		'type'     => 'checkbox',
	) );		
	

}
add_action( 'customize_register', 'salal_customize_register_thumbnail_settings' );
