<?php 
/**
 * Register theme sidebars
 * @package Salal
*/
  
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

function salal_widgets_init() {
	
	register_sidebar( array(
		'name' => esc_html__( 'Blog Sidebar', 'salal' ),
		'id' => 'blog-sidebar',
		'description' => esc_html__( 'Sidebar for your blog and archives.', 'salal' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );	
	register_sidebar( array(
		'name' => esc_html__( 'Page Right Sidebar', 'salal' ),
		'id' => 'right-sidebar',
		'description' => esc_html__( 'Right sidebar for your pages.', 'salal' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );
	register_sidebar( array(
		'name' => esc_html__( 'Page Left Sidebar', 'salal' ),
		'id' => 'left-sidebar',
		'description' => esc_html__( 'Left sidebar for your pages.', 'salal' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );	

	register_sidebar( array(
		'name' => esc_html__( 'Banner', 'salal' ),
		'id' => 'banner',
		'description' => esc_html__( 'For Images and Sliders.', 'salal' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h1 class="widget-title">',
		'after_title' => '</h1>',
	) );	
	register_sidebar( array(
		'name' => esc_html__( 'Breadcrumbs', 'salal' ),
		'id' => 'breadcrumbs',
		'description' => esc_html__( 'For adding breadcrumb navigation if using a plugin, or you can add content here.', 'salal' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<div class="widget-title">',
		'after_title' => '</div>',
	) );	
	register_sidebar( array(
		'name' => esc_html__( 'Bottom 1', 'salal' ),
		'id' => 'bottom1',
		'description' => esc_html__( 'Bottom 1 position', 'salal' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );
	register_sidebar( array(
		'name' => esc_html__( 'Bottom 2', 'salal' ),
		'id' => 'bottom2',
		'description' => esc_html__( 'Bottom 2 position', 'salal' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );
	register_sidebar( array(
		'name' => esc_html__( 'Bottom 3', 'salal' ),
		'id' => 'bottom3',
		'description' => esc_html__( 'Bottom 3 position', 'salal' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );
	register_sidebar( array(
		'name' => esc_html__( 'Bottom 4', 'salal' ),
		'id' => 'bottom4',
		'description' => esc_html__( 'Bottom 4 position', 'salal' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );	
	register_sidebar( array(
		'name' => esc_html__( 'Footer', 'salal' ),
		'id' => 'footer',
		'description' => esc_html__( 'Footer position', 'salal' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h4 class="widget-title">',
		'after_title' => '</h4>',
	) );	
	
	// Register recent posts widget
	register_widget( 'Salal_Recent_Posts_Widget' );
	
}
add_action( 'widgets_init', 'salal_widgets_init' );


// Bottom Sidebars - Add to site
 if ( ! function_exists( 'salal_bottom_sidebars' ) ) {
	
	function salal_bottom_sidebars() { 
	
	// If no active sidebars - then load nothing
	if (   ! is_active_sidebar( 'bottom1'  )
	&& ! is_active_sidebar( 'bottom2' )
	&& ! is_active_sidebar( 'bottom3'  )		
	&& ! is_active_sidebar( 'bottom4'  )	
	)
	return;		
	?> 
   
<div id="bottom-sidebar">
	<aside class="widget-area grid-container">
		   
	<?php if ( is_active_sidebar( 'bottom1' ) ) : ?>
		<div id="bottom1" class="sidebar-column">
			<?php dynamic_sidebar( 'bottom1' ); ?>
		</div>
	<?php endif; ?>

	<?php if ( is_active_sidebar( 'bottom2' ) ) : ?>      
		<div id="bottom2" class="sidebar-column">
			<?php dynamic_sidebar( 'bottom2' ); ?>
		</div>         
	<?php endif; ?>

	<?php if ( is_active_sidebar( 'bottom3' ) ) : ?>        
		<div id="bottom3" class="sidebar-column">
			<?php dynamic_sidebar( 'bottom3' ); ?>
		</div>
	<?php endif; ?>

	<?php if ( is_active_sidebar( 'bottom4' ) ) : ?>        
		<div id="bottom4" class="sidebar-column">
			<?php dynamic_sidebar( 'bottom4' ); ?>
		</div>
	<?php endif; ?>		

	</aside>         
</div>

	<?php }
	}
add_action( 'salal_before_footer', 'salal_bottom_sidebars' );
	
	
	
// Footer Sidebar - Add to site
 if ( ! function_exists( 'salal_footer_sidebar' ) ) :
	
	function salal_footer_sidebar() { 		
		if ( is_active_sidebar( 'footer' ) ) { ?>	
		<aside id="footer-sidebar" class="widget-area">		             
			<?php dynamic_sidebar( 'footer' ); ?> 	
		</aside> 		
		 <?php }
	}
endif;

add_action( 'salal_before_footer_content', 'salal_footer_sidebar' );	



// Banner Sidebar - Add to site
 if ( ! function_exists( 'salal_banner_sidebar' ) ) :
	
	function salal_banner_sidebar() { 	
		 if ( is_active_sidebar( 'banner' ) ) : ?>
		<div id="banner-sidebar" class="widget-area">
			<?php dynamic_sidebar( 'banner' ); ?>
		</div>
		<?php endif; 
	}
endif;

add_action( 'salal_banner', 'salal_banner_sidebar' );	


// Breadcrumbs Sidebar - Add to site
 if ( ! function_exists( 'salal_breadcrumbs_sidebar' ) ) :
	
	function salal_breadcrumbs_sidebar() { 	
		 if ( is_active_sidebar( 'breadcrumbs' ) && is_singular() ) : ?>
		<div id="breadcrumbs-sidebar" class="widget-area">
			<?php dynamic_sidebar( 'breadcrumbs' ); ?>
		</div>
		<?php endif; 
	}
endif;

add_action( 'salal_breadcrumbs', 'salal_breadcrumbs_sidebar' );	

