<?php
/**
 * Custom template tags for this theme
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Salal
 */
 
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}


if ( ! function_exists( 'salal_entry_meta' ) ) :
	/**
	 * Displays the date and author of a post
	 */
	function salal_entry_meta() {

 echo '<ul class="entry-meta post-details">' ;
				salal_entry_date();
				salal_entry_author();
				salal_entry_comments();
				salal_edit_link();

		echo '</ul>';
	}
endif;

if ( ! function_exists( 'salal_entry_date' ) ) :
	// Returns the post date
	function salal_entry_date() {

		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
		if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
			$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
		}

		$time_string = sprintf( $time_string,
			esc_attr( get_the_date( 'c' ) ),
			esc_html( get_the_date() ),
			esc_attr( get_the_modified_date( 'c' ) ),
			esc_html( get_the_modified_date() )
		);
		
		$posted_on = sprintf(
			/* translators: %s: post date */
		__( '<span class="screen-reader-text">Posted on</span> %s', 'salal' ),
		'<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>' );

		echo '<li class="posted-on meta-date">' . $posted_on . '</li>'; // WPCS: XSS OK.	
	}
endif;


if ( ! function_exists( 'salal_entry_author' ) ) :
	// Returns the post author
	function salal_entry_author() {

		$author_string = sprintf( '<span class="author vcard"><a class="url fn n" href="%1$s" title="%2$s" rel="author">%3$s</a></span>',
			esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
			esc_attr( sprintf( 
			/* translators: %s: for the author name */
			esc_html__( 'View all posts by %s', 'salal' ), get_the_author() ) ),
			esc_html( get_the_author() )
		);

		echo '<li class="posted-by meta-author">' . $author_string . '</li>'; // WPCS: XSS OK.	
	}
endif;


if ( ! function_exists( 'salal_entry_comments' ) ) :
	// Displays the post comments
	function salal_entry_comments() {

		if ( ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
			echo '<li class="comments-link">';
				comments_popup_link(
					esc_html__( 'Comment', 'salal' )
				);
			echo '</li>';
		}
	}
endif;



// Get the full category list for a post
if ( ! function_exists( 'salal_categories' ) ) :
function salal_categories() {		
	echo get_the_category_list(); // WPCS: XSS OK.
	}
endif;

// Get just the first category name of a post
function salal_get_first_cat_name() {
	if ( 'post' === get_post_type() ) {
		$cats = get_the_category();
		echo '<div class="post-category">' . esc_html( $cats[0]->name ) . '</div>';
	}
}

// Edit link function
if ( ! function_exists( 'salal_edit_link' ) ) :
	function salal_edit_link() {
		edit_post_link(
			sprintf(
				wp_kses(
					/* translators: %s: Name of current post. Only visible to screen readers */
					__( 'Edit <span class="screen-reader-text">%s</span>', 'salal' ),
					array(
						'span' => array(
							'class' => array(),
						),
					)
				),
				get_the_title()
			),
			'<li class="edit-link">',
			'</li>'
		);
	}
endif;


/**
 * Show the archive title and introduction.
 * Displays the archive title and archive description for categories - tags - etc.
 */
if ( ! function_exists( 'salal_archive_title_group' ) ) :

	function salal_archive_title_group() {
		echo '<header class="archive-header blog-header clearfix">';
		the_archive_title( '<h1 class="archive-title blog-title">', '</h1>' ); 
		the_archive_description( '<div class="archive-description blog-description">', '</div>' );
		echo '</header>';
	}
endif;		
		

if ( ! function_exists( 'salal_more_link' ) ) :
	/**
	 * Displays the more link on posts
	 */
	function salal_more_link() {

		// Get Read More Text.
		$read_more = salal_get_option( 'read_more_text' );

		if ( '' !== $read_more || is_customize_preview() ) :
		?>

    <a href="<?php echo esc_url( get_permalink() ) ?>" class="more-link">
        <?php echo wp_kses_post( $read_more ); ?>
    </a>

    <?php
		endif;
	}
endif;


if ( ! function_exists( 'salal_post_image_archives' ) ) :
	/**
	 * Displays the featured image on archive posts.
	 */
	function salal_post_image_archives() {
	
		// Set image size.
		$image_size = salal_get_option( 'blog_layout' );  ?>

        <?php if (has_post_thumbnail() && true === salal_get_option( 'post_image_archives' )) { ?>
        <div class="post-image">
            <?php 
				if( is_sticky()  && ! is_archive() && esc_attr(get_theme_mod( 'salal_show_featured_tag', true ) ) ) : 
					echo '<div class="ribbon-wrapper-featured"><div class="ribbon-featured">', esc_html_e('Featured', 'salal'), '</div></div>';
				endif; 
				?>
            <a class="wp-post-image-link" href="<?php the_permalink(); ?>" rel="bookmark">
                <?php if ($image_size == 'list' ) :
							the_post_thumbnail( 'salal-list-post' );  								
						elseif ($image_size == 'grid' ) :
							the_post_thumbnail( 'salal-grid-post' );
						elseif ($image_size == 'large' ) :
							the_post_thumbnail( 'salal-large-post' );						
						else :						
							the_post_thumbnail( 'post-thumbnails' ); 							
						endif;	 ?>
            </a>
        </div>

        <?php
		}
	}
endif;


if ( ! function_exists( 'salal_post_image_single' ) ) :
	// Displays the featured image on single posts
	function salal_post_image_single() {
		
		// Display Post Thumbnail if activated.
		if ( true === salal_get_option( 'post_image_single' ) ) : ?>

            <div class="post-image">
                <?php the_post_thumbnail( 'salal-single-post' ); ?>
            </div>

            <?php
		endif;
	}
endif;


if ( ! function_exists( 'salal_entry_footer' ) ) :
	/**
	 * Displays the categories, tags and comments of a post
	 */
	function salal_entry_footer() {

		// Display categories.
		echo salal_categories(); // WPCS: XSS OK.	

		if( is_singular() ) {
			// Display Tags only on single posts.
			salal_entry_tags(); 
		} else {
			// Display comments only on blog index and archives.
			echo salal_entry_comments(); // WPCS: XSS OK.	
		}
	}
endif;

if ( ! function_exists( 'salal_entry_tags' ) ) :
	/**
	 * Displays the post tags on single post view
	 */
	function salal_entry_tags() {

	$tag_list = get_the_tag_list( '<ul class="entry-tags"><li>', '</li><li>', '</li></ul>' );
	 
	if ( $tag_list && ! is_wp_error( $tag_list ) ) {
		echo $tag_list; // WPCS: XSS OK.	
	}		
		
	}
endif;

/**
 * Custom comment output
 */
function salal_comment( $comment, $args, $depth ) { ?>
                <li <?php comment_class( 'clearfix' ); ?> id="li-comment-
                    <?php comment_ID(); ?>">

                    <div id="comment-<?php comment_ID(); ?>" class="comment-body">

                        <div class="comment-wrapper">

                            <div class="comment-author vcard clearfix">
                                <?php echo get_avatar( $comment, 65 ); ?>
                                <h6 class="comment-cite">
                                    <?php comment_author_link() ?>
                                </h6>
                                <span class="comment-date"><?php echo get_comment_date(); ?></span>
                                <span class="comment-edit"><?php edit_comment_link( esc_html__( 'Edit', 'salal' ) ); ?></span>
                            </div>

                            <div class="comment-content">
                                <?php comment_text() ?>
                                <p class="reply">
                                    <?php comment_reply_link( array_merge( $args, array( 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ) ?>
                                </p>
                            </div>

                            <?php if ( $comment->comment_approved == '0' ) : ?>
                            <em class="comment-awaiting-moderation"><?php esc_html_e( 'Your comment is awaiting moderation.', 'salal' ) ?></em>
                            <?php endif; ?>
                        </div>
                    </div>
                    <?php
}

/**
 * Displays pagination on the blog and archive pages
 */
if ( ! function_exists( 'salal_blog_navigation' ) ) :

	function salal_blog_navigation() {

		the_posts_pagination( array(
			'mid_size'  => 2,
			'prev_text' => '<span class="nav-arrow">&laquo</span><span class="screen-reader-text">' . esc_html_x( 'Previous Posts', 'pagination', 'salal' ) . '</span>',
			'next_text' => '<span class="screen-reader-text">' . esc_html_x( 'Next Posts', 'pagination', 'salal' ) . '</span><span class="nav-arrow">&raquo;</span>',
		) );
	}
endif;

/**
 * Displays Single Post Navigation
 */
if ( ! function_exists( 'salal_post_navigation' ) ) :

	function salal_post_navigation() {

		if ( true === salal_get_option( 'post_navigation' ) || is_customize_preview() ) {

			the_post_navigation( array(
				'prev_text' => '<span class="nav-link-text">' . esc_html_x( 'Previous Post', 'post navigation', 'salal' ) . '</span><h5 class="nav-entry-title">%title</h5>',
				'next_text' => '<span class="nav-link-text">' . esc_html_x( 'Next Post', 'post navigation', 'salal' ) . '</span><h5 class="nav-entry-title">%title</h5>',
			) );
		}
	}
endif;

/**
 * Displays Multi-page Navigation
 */
if ( ! function_exists( 'salal_multipage_navigation' ) ) :

	function salal_multipage_navigation() {
		wp_link_pages( array(
		'before' => '<div class="page-links">' . esc_html__( 'Pages:', 'salal' ),
		'after'  => '</div>',
		'link_before' => '<span class="page-wrap">',
		'link_after' => '</span>',
		) ); 
	}
endif;				